@@ -3,14 +3,6 @@
 #include <panda/time.h>
 #include <panda/date.h>
 
-#ifdef _WIN32
-#  define SYSTIMEGM(x)    _mkgmtime(x)
-#  define SYSTIMELOCAL(x) mktime(x)
-#else
-#  define SYSTIMEGM(x)    timegm(x)
-#  define SYSTIMELOCAL(x) timelocal(x)
-#endif
-
 #if IVSIZE >= 8
 #  define SvMIV(x) SvIV(x)
 #  define SvMUV(x) SvUV(x)
